@@ -1,9 +1,13 @@
 pub use retrofit_codegen::get_api;
+pub use rocket;
+pub use reqwest;
+pub use reqwasm;
 
 #[cfg(test)]
 mod tests {
     use retrofit_codegen::get_api;
     use rocket::routes;
+    use crate as retrofit;
 
     #[tokio::test]
     async fn test_get_api() {
